@@ -124,7 +124,13 @@ public class UriBuilderImpl extends UriBuilder implements Cloneable {
 
         UriParts parts = doBuildUriParts(fromEncoded, encodePathSlash, false, values);
         try {
-            return buildURI(fromEncoded, parts.path, parts.query, parts.fragment);
+            final URI uri = buildURI(fromEncoded, parts.path, parts.query, parts.fragment);
+            
+            if (!Rfc3986UriValidator.validate(uri)) {
+                throw new UriBuilderException("[" + uri + "] is not a valid HTTP URL");
+            }
+            
+            return uri;
         } catch (URISyntaxException ex) {
             throw new UriBuilderException("URI can not be built", ex);
         }
@@ -288,7 +294,8 @@ public class UriBuilderImpl extends UriBuilder implements Cloneable {
         }
     }
     //CHECKSTYLE:OFF
-    private String substituteVarargs(URITemplate templ, //NOPMD
+    @SuppressWarnings("PMD.ExcessiveParameterList")
+    private String substituteVarargs(URITemplate templ,
                                      Map<String, Object> alreadyResolvedTs,
                                      Map<String, Object> alreadyResolvedTsPathEnc,
                                      Map<String, Object> alreadyResolvedTsEnc,
@@ -379,7 +386,7 @@ public class UriBuilderImpl extends UriBuilder implements Cloneable {
         for (String var : uniqueVars) {
             boolean isPathEncVar = !isQuery && alreadyResolvedTsPathEnc.containsKey(var);
 
-            boolean isVarEncoded = isPathEncVar || alreadyResolvedTs.containsKey(var) ? false : true;
+            boolean isVarEncoded = !(isPathEncVar || alreadyResolvedTs.containsKey(var));
             Map<String, Object> resolved = isVarEncoded ? alreadyResolvedTsEnc
                 : isPathEncVar ? alreadyResolvedTsPathEnc : alreadyResolvedTs;
             Object oval = resolved.isEmpty() ? null : resolved.remove(var);
@@ -558,7 +565,7 @@ public class UriBuilderImpl extends UriBuilder implements Cloneable {
                 // such empty paths having matrix parameters...
                 int schemeIndex = pathEncoded.indexOf("//");
                 if (schemeIndex != -1) {
-                    int pathComponentStart = pathEncoded.indexOf("/", schemeIndex + 2);
+                    int pathComponentStart = pathEncoded.indexOf('/', schemeIndex + 2);
                     if (pathComponentStart == -1) {
                         this.originalPathEmpty = true;
                         pathComponentStart = pathEncoded.indexOf(';');
